==> openGion6.4.8.1_src.zip: gf/src/org/opengion/fukurou/transfer/TransferExec_PLSQL.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.fukurou.transfer;

import org.opengion.fukurou.system.OgRuntimeException ;		// 6.4.2.0 (2016/01/29)
import java.sql.CallableStatement;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.Types;

import org.opengion.fukurou.db.Transaction;
import org.opengion.fukurou.util.ErrorMessage;
// import org.opengion.fukurou.system.Closer;

/**
 * 伝送要求に対してのPL/SQLを実行します。
 *
 * 実行するPL/SQLのPGIDは、実行対象で指定します。
 * 指定形式は、PG名( ?, ?, ... )  例) GEP00002.GEP00002( ?,?,0 ) です。
 * 引数は、従来のPL/SQLの実行が可能なように、第一引数はエラーコード、第二引数は、
 * エラーメッセージを返してきます。第三引数以降は、自由に指定できます。
 *
 * @og.group 伝送システム
 *
 * @version  5.0
 * @author   Hiroki.Nakamura
 * @since    JDK1.6
 */
public class TransferExec_PLSQL implements TransferExec {

	private static final int DB_MAX_QUERY_TIMEOUT = 6000;

	/**
	 * デフォルトコンストラクター
	 *
	 * @og.rev 6.4.2.0 (2016/01/29) PMD refactoring. Each class should declare at least one constructor.
	 */
	public TransferExec_PLSQL() {
		super();		// これも、自動的に呼ばれるが、空のメソッドを作成すると警告されるので、明示的にしておきます。
	}

	/**
	 * PL/SQLを実行します。
	 *
	 * @og.rev 5.5.2.4 (2012/05/16) クローズされない経路の処理
	 * @og.rev 6.4.2.1 (2016/02/05) try-with-resources 文で記述。
	 *
	 * @param vals 伝送データ(配列)
	 * @param config 伝送設定オブジェクト
	 * @param tran トランザクションオブジェクト
	 */
	@Override
	public void execute( final String[] vals, final TransferConfig config, final Transaction tran ) {
//		CallableStatement callStmt = null;
			final String stmt = "{ call " + config.getExecObj() + "}";
		try {
			final Connection conn = tran.getConnection( config.getExecDbid() );
//			callStmt = conn.prepareCall( stmt );						// 5.5.2.4 (2012/05/16)
			// 6.4.2.1 (2016/02/05) try-with-resources 文
			try( final CallableStatement callStmt = conn.prepareCall( stmt ) ) {
				callStmt.setQueryTimeout( DB_MAX_QUERY_TIMEOUT );
				callStmt.registerOutParameter(1, Types.INTEGER);
				callStmt.registerOutParameter(2, Types.VARCHAR);
				callStmt.execute();

				final int errCode = callStmt.getInt(1);
//				String errMsg = callStmt.getString(2);							// 6.3.6.1 (2015/08/28)

				if( errCode == ErrorMessage.OK ) { // 正常終了の場合
					tran.commit();
				}
				else {
					tran.rollback();
//					errMsg = "PL/SQL実行時に例外が発生しました。" + errMsg;		// 6.3.6.1 (2015/08/28)
					final String errMsg = "PL/SQL実行時に例外が発生しました。"
									+ callStmt.getString(2);
					throw new OgRuntimeException( errMsg );
				}
			}
		}
		catch( SQLException ex ) {
			tran.rollback();
			final String errMsg = "PL/SQL呼出時に例外が発生しました。";
			throw new OgRuntimeException( errMsg, ex );
		}
//		// 5.5.2.4 (2012/05/16)
//		finally {
//			Closer.stmtClose( callStmt );
//		}
	}
}

==> openGion6.7.4.1_src.zip: gf/src/org/opengion/fukurou/transfer/TransferExec_PLSQL.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.fukurou.transfer;

import org.opengion.fukurou.system.OgRuntimeException ;		// 6.4.2.0 (2016/01/29)
import java.sql.CallableStatement;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.Types;

import org.opengion.fukurou.db.Transaction;
import org.opengion.fukurou.util.ErrorMessage;
// import org.opengion.fukurou.system.Closer;

/**
 * 伝送要求に対してのPL/SQLを実行します。
 *
 * 実行するPL/SQLのPGIDは、実行対象で指定します。
 * 指定形式は、PG名( ?, ?, ... )  例) GEP00002.GEP00002( ?,?,0 ) です。
 * 引数は、従来のPL/SQLの実行が可能なように、第一引数はエラーコード、第二引数は、
 * エラーメッセージを返してきます。第三引数以降は、自由に指定できます。
 *
 * @og.group 伝送システム
 *
 * @version  5.0
 * @author   Hiroki.Nakamura
 * @since    JDK1.6
 */
public class TransferExec_PLSQL implements TransferExec {

	private static final int DB_MAX_QUERY_TIMEOUT = 6000;

	/**
	 * デフォルトコンストラクター
	 *
	 * @og.rev 6.4.2.0 (2016/01/29) PMD refactoring. Each class should declare at least one constructor.
	 */
	public TransferExec_PLSQL() {
		super();		// これも、自動的に呼ばれるが、空のメソッドを作成すると警告されるので、明示的にしておきます。
	}

	/**
	 * PL/SQLを実行します。
	 *
	 * @og.rev 5.5.2.4 (2012/05/16) クローズされない経路の処理
	 * @og.rev 6.4.2.1 (2016/02/05) try-with-resources 文で記述。
	 *
	 * @param vals 伝送データ(配列)
	 * @param config 伝送設定オブジェクト
	 * @param tran トランザクションオブジェクト
	 */
	@Override
	public void execute( final String[] vals, final TransferConfig config, final Transaction tran ) {
//		CallableStatement callStmt = null;
			final String stmt = "{ call " + config.getExecObj() + "}";
		try {
			final Connection conn = tran.getConnection( config.getExecDbid() );
//			callStmt = conn.prepareCall( stmt );						// 5.5.2.4 (2012/05/16)
			// 6.4.2.1 (2016/02/05) try-with-resources 文
			try( final CallableStatement callStmt = conn.prepareCall( stmt ) ) {
				callStmt.setQueryTimeout( DB_MAX_QUERY_TIMEOUT );
				callStmt.registerOutParameter(1, Types.INTEGER);
				callStmt.registerOutParameter(2, Types.VARCHAR);
				callStmt.execute();

				final int errCode = callStmt.getInt(1);
//				String errMsg = callStmt.getString(2);							// 6.3.6.1 (2015/08/28)

				if( errCode == ErrorMessage.OK ) { // 正常終了の場合
					tran.commit();
				}
				else {
					tran.rollback();
//					errMsg = "PL/SQL実行時に例外が発生しました。" + errMsg;		// 6.3.6.1 (2015/08/28)
					final String errMsg = "PL/SQL実行時に例外が発生しました。"
									+ callStmt.getString(2);
					throw new OgRuntimeException( errMsg );
				}
			}
		}
		catch( final SQLException ex ) {
			tran.rollback();
			final String errMsg = "PL/SQL呼出時に例外が発生しました。";
			throw new OgRuntimeException( errMsg, ex );
		}
//		// 5.5.2.4 (2012/05/16)
//		finally {
//			Closer.stmtClose( callStmt );
//		}
	}
}
